@@ -33,8 +33,13 @@ def authorized(handler):
             for key, value in query_params.items():
                 data[key] = value
 
+        query_params = dict(request.args)
+        if query_params and query_params.get('company_id'):
+            data['company_id'] = query_params.get('company_id')
+
         try:
-            response = requests.post(url=url, headers=headers, data=json.dumps(data))
+            response = requests.post(
+                url=url, headers=headers, data=json.dumps(data))
             if response.status_code == 200:
                 return handler(auth_info=response.json(), *args, **kwargs)
             return response.json(), response.status_code
