@@ -245,8 +245,9 @@ class Util:
 
 # [START cloud_tasks_create_queue]
 
+
     @classmethod
-    def enqueue_http_request(cls, url, payload=None):
+    def enqueue_http_request(cls, url, payload=None, in_seconds=None):
         project = os.getenv('PROJECT_ID')
         location = os.getenv('LOCATION')
         queue_name = os.getenv('QUEUE_NAME')
@@ -266,7 +267,7 @@ class Util:
             create_task_response = cls.create_http_task(project=project, queue=queue_name, location=location,
                                                         task_name='{}_{}'.format(
                                                             os.getenv('TASK_NAME_PREFIX'), cls.generate_random_string()),
-                                                        url=url, payload=payload)
+                                                        url=url, payload=payload, in_seconds=in_seconds)
 
             return "success"
         except Exception as e:
@@ -371,7 +372,7 @@ class Util:
 
         if in_seconds is not None:
             # Convert "seconds from now" into an rfc3339 datetime string.
-            d = datetime.datetime.utcnow() + datetime.timedelta(seconds=in_seconds)
+            d = datetime.utcnow() + datetime.timedelta(seconds=in_seconds)
 
             # Create Timestamp protobuf.
             timestamp = timestamp_pb2.Timestamp()
@@ -393,3 +394,11 @@ class Util:
         return response
 
 # [END create_http_task]
+
+    @classmethod
+    def log_exception(cls, e):
+        import os
+        if not os.getenv('IS_DEV'):
+            from google.cloud import error_reporting
+            client = error_reporting.Client()
+            client.report_exception(e)
